@@ -15,8 +15,8 @@
 #' @param node.label.force the repelling force between overlapping labels
 #' @param node.shape an integer specifying node shape or a character specifying which node attribute used for the node shape (no matter whether it is numeric or character)
 #' @param node.shape.title a character specifying the title for node shaping
-#' @param node.xcoord a vector specifying x coordinates. If NULL, it will be created using igraph::layout_with_kk
-#' @param node.ycoord a vector specifying y coordinates. If NULL, it will be created using igraph::layout_with_kk
+#' @param node.xcoord a vector specifying x coordinates. If NULL, it will be created using igraph::layout_as_tree
+#' @param node.ycoord a vector specifying y coordinates. If NULL, it will be created using igraph::layout_as_tree
 #' @param node.color a character specifying which node attribute used for node coloring
 #' @param node.color.title a character specifying the title for node coloring
 #' @param colormap short name for the colormap. It can be one of "jet" (jet colormap), "bwr" (blue-white-red colormap), "gbr" (green-black-red colormap), "wyr" (white-yellow-red colormap), "br" (black-red colormap), "yr" (yellow-red colormap), "wb" (white-black colormap), "rainbow" (rainbow colormap, that is, red-yellow-green-cyan-blue-magenta), and "ggplot2" (emulating ggplot2 default color palette). Alternatively, any hyphen-separated HTML color names, e.g. "lightyellow-orange" (by default), "blue-black-yellow", "royalblue-white-sandybrown", "darkgreen-white-darkviolet". A list of standard color names can be found in \url{http://html-color-codes.info/color-names}
@@ -46,6 +46,7 @@
 #' library(XGR)
 #' RData.location <- "http://galahad.well.ox.ac.uk/bigdata_dev/"
 #' 
+#' ###########################
 #' # load REACTOME
 #' # restricted to Immune System ('R-HSA-168256') or Signal Transduction ('R-HSA-162582')
 #' g <- xRDataLoader(RData.customised='ig.REACTOME', RData.location=RData.location)
@@ -61,6 +62,32 @@
 #' gp <- xGGnetwork(g=ls_ig, node.label='term_id', label.wrap.width=30, node.label.size=2, node.label.color='black', node.label.alpha=0.8, node.label.padding=0, node.label.arrow=0, node.label.force=1, node.shape=19, node.xcoord='xcoord', node.ycoord='ycoord', node.color='degree', node.color.title='Degree', colormap='grey-orange-darkred', ncolors=64, zlim=c(0,10), node.size.range=3, edge.color="black",edge.color.alpha=0.3,edge.curve=0.05,edge.arrow.gap=0.02, title='')
 #' 
 #' ###########################
+#' # load PhasedTargets
+#' # restricted to disease ('EFO:0000408') or immune system disease ('EFO:0000540')
+#' g <- xRDataLoader(RData.customised='ig.PhasedTargets', RData.location=RData.location)
+#' neighs.out <- igraph::neighborhood(g, order=vcount(g), nodes="EFO:0000408", mode="out")
+#' nodeInduced <- V(g)[unique(unlist(neighs.out))]$name
+#' ig <- igraph::induced.subgraph(g, vids=nodeInduced)
+#'
+#' # append with the number of approved and phased targets
+#' dag <- ig
+#' V(dag)$num_approved <- sapply(V(ig)$max_phase,function(x) sum(x$max_phase>=4))
+#' V(dag)$num_phased <- sapply(V(ig)$max_phase,function(x) sum(x$max_phase>=0))
+#' # keep nodes with num_approved >=20
+#' dag_ig <- igraph::induced.subgraph(dag, vids=which(V(dag)$num_approved>=20))
+#' # (optional) further restricted to the direct children of the root
+#' root <- dnet::dDAGroot(dag_ig)
+#' neighs.out <- igraph::neighborhood(dag_ig, order=1, nodes=root, mode="out")
+#' nodeInduced <- V(dag_ig)[unique(unlist(neighs.out))]$name
+#' dag_ig <- igraph::induced.subgraph(dag_ig, vids=nodeInduced)
+#' # nodes colored by num_approved
+#' V(dag_ig)$node_color <- log2(V(dag_ig)$num_approved)
+#' glayout <- igraph::layout_with_kk(dag_ig)
+#' V(dag_ig)$xcoord <- glayout[,1]
+#' V(dag_ig)$ycoord <- glayout[,2]
+#' gp <- xGGnetwork(g=dag_ig, node.label='term_name', label.wrap.width=30, node.label.size=2, node.label.color='black', node.label.alpha=0.9, node.label.padding=0, node.label.arrow=0, node.label.force=0.5, node.shape=19, node.xcoord='xcoord', node.ycoord='ycoord', node.color='node_color', node.color.title='Approved\n(log2-scale)', colormap='ggplot2.top', ncolors=64, node.size.range=3, edge.color="orange",edge.color.alpha=0.5,edge.curve=0.05,edge.arrow.gap=0.02, title='')
+#' 
+#' ###########################
 #' # visualise gene network
 #' glayout <- igraph::layout_with_kk(g)
 #' V(g)$xcoord <- glayout[,1]
@@ -122,6 +149,9 @@ xGGnetwork <- function(g, node.label=NULL, label.wrap.width=NULL, label.wrap.lin
 				## layout
 				#glayout <- igraph::layout_with_kk(ig)
 				glayout <- igraph::layout_as_tree(ig,root=dnet::dDAGroot(ig),circular=TRUE,flip.y=TRUE)
+				if(all(is.na(glayout))){
+					glayout <- igraph::layout_with_kk(ig)
+				}
 				glayout <- glayout[,c(2:1)]
 				node.xcoord <- glayout[,1]
 				node.ycoord <- glayout[,2]
@@ -301,7 +331,7 @@ xGGnetwork <- function(g, node.label=NULL, label.wrap.width=NULL, label.wrap.lin
     df$n.size <- as.numeric(df$n.size)
 
     ## make sure factor    
-    df$n.shape <- factor(df$n.shape, levels=unique(df$n.shape))
+    df$n.shape <- factor(df$n.shape, levels=sort(unique(df$n.shape)))
     
     #############################################################
     n.color <- n.size <- n.shape <- n.label <- n.label.size <- n.label.color <- NULL
@@ -318,6 +348,11 @@ xGGnetwork <- function(g, node.label=NULL, label.wrap.width=NULL, label.wrap.lin
 	}
 	
 	if(length(unique(df$n.shape))==1){
+		#####################################
+		if(!is.numeric(node.shape)){
+			node.shape <- 19
+		}
+		#####################################		
 		gp <- gp + ggnetwork::geom_nodes(aes(color=n.color,size=n.size), shape=node.shape)
 	}else{
 		gp <- gp + ggnetwork::geom_nodes(aes(color=n.color,size=n.size, shape=n.shape))
@@ -353,7 +388,7 @@ xGGnetwork <- function(g, node.label=NULL, label.wrap.width=NULL, label.wrap.lin
 	}
 	
 	gp <- gp + ggnetwork::theme_blank()
-	gp <- gp + theme(text=element_text(family="sans")) + labs(title=title) + theme(plot.title=element_text(hjust=0.5), plot.margin=unit(rep(0,4),rep("lines",4)))
+	gp <- gp + theme(text=element_text(family="sans")) + labs(title=title) + theme(plot.title=element_text(hjust=0.5,size=10,face="bold"), plot.margin=unit(rep(0,4),rep("lines",4)))
 	
 	if((zlim[1]!=zlim[2]) & (slim[1]!=slim[2])){
 		gp <- gp + theme(legend.position="right")
